"use strict";

const visit = require(`unist-util-visit`);

const parseLineNumberRange = require(`./parse-line-number-range`);

const highlightCode = require(`./highlight-code`);

module.exports = ({
  markdownAST
}, {
  inlineCodeMarker = null,
  aliases = {}
} = {}) => {
  const normalizeLanguage = lang => {
    const lower = lang.toLowerCase();
    return aliases[lower] || lower;
  };

  visit(markdownAST, `code`, node => {
    let language = node.lang;

    let _parseLineNumberRange = parseLineNumberRange(language),
        splitLanguage = _parseLineNumberRange.splitLanguage,
        highlightLines = _parseLineNumberRange.highlightLines;

    language = splitLanguage; // PrismJS's theme styles are targeting pre[class*="language-"]
    // to apply its styles. We do the same here so that users
    // can apply a PrismJS theme and get the expected, ready-to-use
    // outcome without any additional CSS.
    //
    // @see https://github.com/PrismJS/prism/blob/1d5047df37aacc900f8270b1c6215028f6988eb1/themes/prism.css#L49-L54

    let languageName = `text`;

    if (language) {
      languageName = normalizeLanguage(language);
    } // Replace the node with the markup we need to make
    // 100% width highlighted code lines work


    node.type = `html`;
    node.value = `<pre class="code" data-lang="${languageName}"><code>${highlightCode(language, node.value, highlightLines)}</code></pre>`;
  });
  visit(markdownAST, `inlineCode`, node => {
    let languageName = `text`;

    if (inlineCodeMarker) {
      let _node$value$split = node.value.split(`${inlineCodeMarker}`, 2),
          language = _node$value$split[0],
          restOfValue = _node$value$split[1];

      if (language && restOfValue) {
        languageName = normalizeLanguage(language);
        node.value = restOfValue;
      }
    }

    node.type = `html`;
    node.value = `<code>${highlightCode(languageName, node.value)}</code>`;
  });
};